@@ -4,6 +4,8 @@ import tw2.core as twc
 from tw2.jquery import jquery_js
 import json
 
+setup_call = twc.js_function('setupPollingDynText')
+
 class DynamicTextWidget(twc.Widget):
     template = "mako:tw2.dyntext.templates.dyntext"
 
@@ -29,4 +31,5 @@ class DynamicTextWidget(twc.Widget):
 
         super(DynamicTextWidget, self).prepare()
         # put code here to run just before the widget is displayed
-        self.selector = self.attrs['id'].replace(':', '\\\\:')
+        self.selector = self.attrs['id'].replace(':', '\\:')
+        self.add_call(setup_call(self.selector, self.data_url, self.interval))
